@@ -904,7 +904,7 @@ class XAPIAN_VISIBILITY_DEFAULT Enquire {
 	 *
 	 * @param sort_key  value number to sort on.
 	 *
-	 * @param reverse   If true, reverses the sort order.
+	 * @param reverse   If true, reverses the sort order of sort_key.
 	 */
 	void set_sort_by_relevance_then_value(Xapian::valueno sort_key,
 					      bool reverse);
@@ -923,7 +923,8 @@ class XAPIAN_VISIBILITY_DEFAULT Enquire {
 	 *
 	 * @param sorter    The functor to use for generating keys.
 	 *
-	 * @param reverse   If true, reverses the sort order.
+	 * @param reverse   If true, reverses the sort order of the generated
+	 *		    keys.
 	 */
 	void set_sort_by_relevance_then_key(Xapian::KeyMaker * sorter,
 					    bool reverse);
